import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:transparent_image/transparent_image.dart';

import 'custom-widget-provider/custom-services.dart';

Widget customImage(
    CustomImageContents data,
    void Function() onTapImage,
    ) {
  return GestureDetector(
    onTap: () {
      return (onTapImage != null) ? onTapImage() : null;
    },
    child: Row(
      mainAxisAlignment: data.imageAlignment=='Left' ? MainAxisAlignment.start :
      data.imageAlignment=='Center' ? MainAxisAlignment.center : MainAxisAlignment.end,
      children: [
        Column(
          mainAxisSize: MainAxisSize.min,
          children: [
            Container(
              color: data.color,
              child: data.captionAlignment=='bottom' ?
              Column(
                mainAxisSize: MainAxisSize.min,
                children: [
                  data.colorBlendMode==BlendMode.multiply ?   // new line added
                  Container(
                      height: data.height,
                      width: data.width,
                      padding: EdgeInsets.only(
                          left: data.imageLeftPadding,
                          right: data.imageRightPadding,
                          top: data.imageTopPadding,
                          bottom: data.imageBottomPadding),
                      child:FadeInImage.memoryNetwork(// new line added
                        placeholder: kTransparentImage,   // new line added
                        image: data.src,   // new line added
                      )) :   // new line added
                  Container(
                    height: data.height,
                    width: data.width,
                    decoration: new BoxDecoration(
                      borderRadius: BorderRadius.all(Radius.circular(data.imageBorderRadius)),
                      border: Border.all(color: data.color,width: 0), // new line added
                      image: DecorationImage(
                          image: NetworkImage(data.src,),
                          colorFilter: new ColorFilter.mode(
                              data.color.withOpacity(0.9), data.colorBlendMode), //new line added
                          fit: data.fit),
                    ),
                  ),
                  if(data.showCaption != false && data.caption != null)
                    Container(
                      child: Padding(
                        padding: EdgeInsets.only(
                            left: data.captionLeftPadding,
                            right: data.captionRightPadding,
                            top: data.captionTopPadding,
                            bottom: data.captionBottomPadding),
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          mainAxisSize: MainAxisSize.min,
                          children: [
                            Row(
                              mainAxisAlignment: MainAxisAlignment.start,
                              children: [
                                Padding(
                                    padding: const EdgeInsets.all(0.0),
                                    child:Text(data.caption,
                                        style: GoogleFonts.getFont( checkFonts(data.fontFamily),
                                          fontSize: data.captionFontSize,
                                          color: data.overlayTextColor,
                                        ))
                                ),
                              ],
                            ),
                          ],
                        ),
                      ),
                    ),
                ],
              ):
              data.captionAlignment=='top'?
              Column(
                children: [
                  if(data.showCaption != false && data.caption != null)
                    Container(
                      child: Padding(
                        padding: EdgeInsets.only(
                            left: data.captionLeftPadding,
                            right: data.captionRightPadding,
                            top: data.captionTopPadding,
                            bottom: data.captionBottomPadding),
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          mainAxisSize: MainAxisSize.min,
                          children: [
                            Row(
                              mainAxisAlignment: MainAxisAlignment.start,
                              children: [
                                Padding(
                                    padding: const EdgeInsets.all(0.0),
                                    child: Text(data.caption,
                                        style: GoogleFonts.getFont( checkFonts(data.fontFamily),
                                          fontSize: data.captionFontSize,
                                          color: data.overlayTextColor,
                                        ))
                                ),
                              ],
                            ),
                          ],
                        ),
                      ),
                    ),
                  Padding(
                    padding: EdgeInsets.only(
                        left: data.imageLeftPadding,
                        right: data.imageRightPadding,
                        top: data.imageTopPadding,
                        bottom: data.imageBottomPadding),
                    child:data.colorBlendMode==BlendMode.multiply ?   // new line added
                    Container(
                        height: data.height,
                        width: data.width,
                        child:FadeInImage.memoryNetwork(// new line added
                          placeholder: kTransparentImage,   // new line added
                          image: data.src,   // new line added
                        )) :   // new line added
                    Container(
                      height: data.height,
                      width: data.width,
                      decoration: new BoxDecoration(
                        borderRadius: BorderRadius.all(Radius.circular(data.imageBorderRadius)),
                        border: Border.all(color: data.color,width: 0), // new line added
                        image: DecorationImage(
                            image: NetworkImage(data.src),
                            colorFilter: new ColorFilter.mode(
                                data.color.withOpacity(data.imageOpacity), data.colorBlendMode), //new line added
                            fit: data.fit),
                      ),
                    ),
                  ),
                ],
              ):
              data.captionAlignment=='left'?
              Row(
                children: [
                  if(data.showCaption != false && data.caption != null)
                    Container(
                      child: Padding(
                        padding: EdgeInsets.only(
                            left: data.captionLeftPadding,
                            right: data.captionRightPadding,
                            top: data.captionTopPadding,
                            bottom: data.captionBottomPadding),
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          mainAxisSize: MainAxisSize.min,
                          children: [
                            Row(
                              mainAxisAlignment: MainAxisAlignment.start,
                              children: [
                                Padding(
                                  padding: const EdgeInsets.all(0.0),
                                  child : Text(data.caption,
                                      style: GoogleFonts.getFont( checkFonts(data.fontFamily),
                                        fontSize: data.captionFontSize,
                                        color: data.overlayTextColor,
                                      )),
                                ),
                              ],
                            ),
                          ],
                        ),
                      ),
                    ),
                  Padding(
                    padding: EdgeInsets.only(
                        left: data.imageLeftPadding,
                        right: data.imageRightPadding,
                        top: data.imageTopPadding,
                        bottom: data.imageBottomPadding),
                    child:data.colorBlendMode==BlendMode.multiply ?   // new line added
                    Container(
                        height: data.height,
                        width: data.width,
                        child:FadeInImage.memoryNetwork(// new line added
                          placeholder: kTransparentImage,   // new line added
                          image: data.src,   // new line added
                        )) :   // new line added
                    Container(
                      height: data.height,
                      width: data.width,
                      decoration: new BoxDecoration(
                        borderRadius: BorderRadius.all(Radius.circular(data.imageBorderRadius)),
                        border: Border.all(color: data.color,width: 0), // new line added
                        image: DecorationImage(
                            image: NetworkImage(data.src),
                            colorFilter: new ColorFilter.mode(
                                data.color.withOpacity(data.imageOpacity), data.colorBlendMode), //new line added
                            fit: data.fit),
                      ),
                    ),
                  ),
                ],
              ):
              Row(
                children: [
                  Padding(
                    padding: EdgeInsets.only(
                        left: data.imageLeftPadding,
                        right: data.imageRightPadding,
                        top: data.imageTopPadding,
                        bottom: data.imageBottomPadding),
                    child:data.colorBlendMode==BlendMode.multiply ?   // new line added
                    Container(
                        height: data.height,
                        width: data.width,
                        child:FadeInImage.memoryNetwork(// new line added
                          placeholder: kTransparentImage,   // new line added
                          image: data.src,   // new line added
                        )) :   // new line added
                    Container(
                      height: data.height,
                      width: data.width,
                      decoration: new BoxDecoration(
                        borderRadius: BorderRadius.all(Radius.circular(data.imageBorderRadius)),
                        border: Border.all(color: data.color,width: 0), // new line added
                        image: DecorationImage(
                            image: NetworkImage(data.src),
                            colorFilter: new ColorFilter.mode(
                                data.color.withOpacity(data.imageOpacity), data.colorBlendMode), //new line added
                            fit: data.fit),
                      ),
                    ),
                  ),
                  if(data.showCaption != false && data.caption != null)
                    Container(
                      child: Padding(
                        padding: EdgeInsets.only(
                            left: data.captionLeftPadding,
                            right: data.captionRightPadding,
                            top: data.captionTopPadding,
                            bottom: data.captionBottomPadding),
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          mainAxisSize: MainAxisSize.min,
                          children: [
                            Row(
                              mainAxisAlignment: MainAxisAlignment.start,
                              children: [
                                Padding(
                                    padding: const EdgeInsets.all(0.0),
                                    child : Text(data.caption,
                                        style: GoogleFonts.getFont( checkFonts(data.fontFamily),
                                          fontSize: data.captionFontSize,
                                          color: data.overlayTextColor,
                                        ))
                                ),
                              ],
                            ),
                          ],
                        ),
                      ),
                    ),
                ],
              ),
            ),
          ],
        ),
      ],
    ),
  );
}

Widget ImageWithOverlay(CustomImageContents data) {
  return Container(
    padding: EdgeInsets.only(
        left: data.imageLeftPadding,
        right: data.imageRightPadding,
        top: data.imageTopPadding,
        bottom: data.imageBottomPadding),
    child: Stack(
      children: <Widget>[
        ColorFiltered(
          colorFilter: ColorFilter.mode(
              data.color.withOpacity(data.imageOpacity), data.colorBlendMode),
          child: Image(
            image: NetworkImage(data.src),
            fit: BoxFit.fill,
            semanticLabel: data.semanticLabel,
          ),
        ),
        data.showoverlayText
            ? Align(
            alignment: data.overlayTextAlignment,
            child: Text(data.overlayText,
                style: GoogleFonts.getFont(
                  checkFonts(data.fontFamily),
                  fontSize: data.overlayTextFontSize,
                  color: data.overlayTextColor,
                )))
            : SizedBox.shrink(),
      ],
    ),
  );
}

Widget CaptionText(CustomImageContents data) {
  return Padding(
    padding: EdgeInsets.only(
        left: data.captionLeftPadding,
        right: data.captionRightPadding,
        top: data.captionTopPadding,
        bottom: data.captionBottomPadding),
    child: Text(data.caption.trim(),
        style: GoogleFonts.getFont(
          checkFonts(data.fontFamily),
          fontSize: data.captionFontSize,
          color: data.captionColor,
        )),
  );
}
